@@ -1,8 +1,28 @@
-/*
- * Copyright (c) 2000-2005, Index Data.
- * See the file LICENSE for details.
- * 
- * $Id: z-server.h,v 1.1 2006/03/29 13:14:15 adam Exp $
+/* This file is part of the yazpp toolkit.
+ * Copyright (C) 1998-2008 Index Data and Mike Taylor
+ * All rights reserved.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *     * Redistributions of source code must retain the above copyright
+ *       notice, this list of conditions and the following disclaimer.
+ *     * Redistributions in binary form must reproduce the above copyright
+ *       notice, this list of conditions and the following disclaimer in the
+ *       documentation and/or other materials provided with the distribution.
+ *     * Neither the name of Index Data nor the names of its contributors
+ *       may be used to endorse or promote products derived from this
+ *       software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
+ * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
+ * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 #include <yazpp/z-assoc.h>
@@ -14,7 +34,7 @@ class Z_Server;
 class YAZ_EXPORT Z_ServerUtility {
  public:
     void create_databaseRecord (ODR odr, Z_NamePlusRecord *rec,
-                                const char *dbname, int format,
+                                const char *dbname, const Odr_oid *format,
                                 const void *buf, int len);
     void create_surrogateDiagnostics(ODR odr, Z_NamePlusRecord *rec,
                                      const char *dbname, int error,
@@ -81,10 +101,10 @@ class YAZ_EXPORT Yaz_Facility_Retrieval : public IServer_Facility,
                              Z_PresentResponse *presentResponse) = 0;
     virtual void sr_record (const char *resultSetName,
                             int position,
-                            int *format,
-                                Z_RecordComposition *comp,
-                                Z_NamePlusRecord *namePlusRecord,
-                                Z_Records *diagnostics) = 0;
+                            Odr_oid *format,
+                            Z_RecordComposition *comp,
+                            Z_NamePlusRecord *namePlusRecord,
+                            Z_Records *diagnostics) = 0;
     int init(Z_Server *server,
              Z_InitRequest *initRequest,
              Z_InitResponse *initResponse);
@@ -98,7 +118,7 @@ class YAZ_EXPORT Yaz_Facility_Retrieval : public IServer_Facility,
                              int start, int num,
                              Z_RecordComposition *comp,
                              int *next, int *pres,
-                             int *oid);
+                             Odr_oid *oid);
 
     void fetch_via_piggyback (Z_Server *s,
                               Z_SearchRequest *searchRequest,
