@@ -1,8 +1,6 @@
-/*
- * Copyright (c) 1998-2005, Index Data.
+/* This file is part of the yazpp toolkit.
+ * Copyright (C) 1998-2008 Index Data and Mike Taylor
  * See the file LICENSE for details.
- * 
- * $Id: tstquery.cpp,v 1.2 2006/03/29 13:14:15 adam Exp $
  */
 
 #include <stdlib.h>
@@ -34,8 +32,8 @@ void tst1(const char *query_str_in, const char *query_expected)
 int main(int argc, char **argv)
 {
     tst1("", "");
-    tst1("x", "RPN: @attrset Bib-1 x");
-    tst1("@and a b", "RPN: @attrset Bib-1 @and a b");
+    tst1("x", "RPN @attrset Bib-1 x");
+    tst1("@and a b", "RPN @attrset Bib-1 @and a b");
 }
 
 /*
