@@ -1,8 +1,6 @@
-/*
- * Copyright (c) 1998-2004, Index Data.
+/* This file is part of the yazpp toolkit.
+ * Copyright (C) 1998-2008 Index Data and Mike Taylor
  * See the file LICENSE for details.
- * 
- * $Id: yaz-cql2rpn.cpp,v 1.9 2006/03/29 13:14:15 adam Exp $
  */
 
 #include <yaz/log.h>
@@ -28,6 +26,15 @@ void Yaz_cql2rpn::set_pqf_file(const char *fname)
         m_transform = cql_transform_open_fname(fname);
 }
 
+
+bool Yaz_cql2rpn::parse_spec_file(const char *fname, int *error)
+{
+    *error = 0;
+    cql_transform_close(m_transform);
+    m_transform = cql_transform_open_fname(fname);
+    return m_transform ? true : false;
+}
+
 int Yaz_cql2rpn::query_transform(const char *cql_query, 
                                  Z_RPNQuery **rpnquery, ODR o,
                                  char **addinfop)
@@ -40,12 +47,11 @@ int Yaz_cql2rpn::query_transform(const char *cql_query,
     int r = cql_parser_string(cp, cql_query);
     if (r)
     {
-        yaz_log(YLOG_LOG, "CQL Parse Error");
         r = 10;
     }
     else
     {
-        char rpn_buf[1024];
+        char rpn_buf[10240];
         r = cql_transform_buf(m_transform, cql_parser_result(cp), 
                               rpn_buf, sizeof(rpn_buf)-1);
         if (!r)
@@ -57,9 +63,7 @@ int Yaz_cql2rpn::query_transform(const char *cql_query,
             {
                 size_t off;
                 const char *pqf_msg;
-                int code = yaz_pqf_error(pp, &pqf_msg, &off);
-                yaz_log(YLOG_WARN, "PQF Parser Error %s (code %d)",
-                        pqf_msg, code);
+                yaz_pqf_error(pp, &pqf_msg, &off);
                 r = -1;
             }
             yaz_pqf_destroy(pp);
@@ -67,8 +71,6 @@ int Yaz_cql2rpn::query_transform(const char *cql_query,
         else
         {
             r = cql_transform_error(m_transform, &addinfo);
-            yaz_log(YLOG_LOG, "CQL Transform Error %d %s", r,
-                    addinfo ? addinfo : "");
         }
     }   
     cql_parser_destroy(cp);
