@@ -1,9 +1,6 @@
-/*
- * Copyright (c) 2000-2004, Index Data.
+/* This file is part of the yazpp toolkit.
+ * Copyright (C) 1998-2008 Index Data and Mike Taylor
  * See the file LICENSE for details.
- * 
- * $Id: yaz-z-server-sr.cpp,v 1.12 2006/03/29 13:14:18 adam Exp $
- *
  */
 
 #include <yaz/log.h>
@@ -16,7 +13,7 @@ Z_Records *Yaz_Facility_Retrieval::pack_records (Z_Server *s,
                                                  int start, int xnum,
                                                  Z_RecordComposition *comp,
                                                  int *next, int *pres,
-                                                 int *format)
+                                                 Odr_oid *format)
 {
     int recno, total_length = 0, toget = xnum, dumped_records = 0;
     Z_Records *records =
