@@ -1,12 +1,11 @@
-/*
- * Copyright (c) 2000-2004, Index Data.
+/* This file is part of the yazpp toolkit.
+ * Copyright (C) 1998-2008 Index Data and Mike Taylor
  * See the file LICENSE for details.
- * 
- * $Id: yaz-z-server.cpp,v 1.24 2006/03/29 13:14:18 adam Exp $
  */
 
 #include <yaz/log.h>
 #include <yazpp/z-server.h>
+#include <yaz/oid_db.h>
 
 using namespace yazpp_1;
 
@@ -112,13 +111,14 @@ void Z_Server::recv_Z_PDU (Z_APDU *apdu_request, int len)
  * database record.
  */
 void Z_ServerUtility::create_databaseRecord (
-    ODR odr, Z_NamePlusRecord *rec, const char *dbname, int format,
+    ODR odr, Z_NamePlusRecord *rec, const char *dbname, const Odr_oid *format,
     const void *buf, int len)
 {
+    Odr_oid *oid = odr_oiddup(odr, format);
     rec->databaseName = dbname ? odr_strdup (odr, dbname) : 0;
     rec->which = Z_NamePlusRecord_databaseRecord;
-    rec->u.databaseRecord = z_ext_record (odr, format,
-                                          (const char *) buf, len);
+    rec->u.databaseRecord = z_ext_record_oid(odr, oid,
+                                             (const char *) buf, len);
 }
 
 /*
@@ -140,8 +140,7 @@ void Z_ServerUtility::create_surrogateDiagnostics(
     rec->u.surrogateDiagnostic = drec;
     drec->which = Z_DiagRec_defaultFormat;
     drec->u.defaultFormat = dr;
-    dr->diagnosticSetId =
-        yaz_oidval_to_z3950oid (odr, CLASS_DIAGSET, VAL_BIB1);
+    dr->diagnosticSetId = odr_oiddup(odr, yaz_oid_diagset_bib_1);
 
     dr->condition = err;
     dr->which = Z_DefaultDiagFormat_v2Addinfo;
@@ -163,8 +162,7 @@ Z_Records *Z_ServerUtility::create_nonSurrogateDiagnostics (
     *err = error;
     rec->which = Z_Records_NSD;
     rec->u.nonSurrogateDiagnostic = dr;
-    dr->diagnosticSetId =
-        yaz_oidval_to_z3950oid (odr, CLASS_DIAGSET, VAL_BIB1);
+    dr->diagnosticSetId = odr_oiddup(odr, yaz_oid_diagset_bib_1);
 
     dr->condition = err;
     dr->which = Z_DefaultDiagFormat_v2Addinfo;
@@ -186,8 +184,7 @@ void Z_ServerUtility::create_diagnostics (
         
     drec->which = Z_DiagRec_defaultFormat;
     drec->u.defaultFormat = dr;
-    dr->diagnosticSetId =
-        yaz_oidval_to_z3950oid (odr, CLASS_DIAGSET, VAL_BIB1);
+    dr->diagnosticSetId = odr_oiddup(odr, yaz_oid_diagset_bib_1);
     dr->condition = odr_intdup (odr, error);
     dr->which = Z_DefaultDiagFormat_v2Addinfo;
     dr->u.v2Addinfo = odr_strdup (odr, addinfo ? addinfo : "");
